#
# spec file for package libbde
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libbde1
Name:           libbde
Version:        20231106
Release:        1.1
Summary:        Library and tools to access Microsoft Bitlocker Disk Encrypted partitions
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libbde
Source:         https://github.com/libyal/libbde/releases/download/%version/libbde-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libbde/releases/download/%version/libbde-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source10:       BitLocker_Drive_Encryption_BDE_format.pdf
BuildRequires:  %python_module devel
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcaes) >= 20230406
BuildRequires:  pkgconfig(libcdata) >= 20230108
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libfcache) >= 20230115
BuildRequires:  pkgconfig(libfdatetime) >= 20220112
BuildRequires:  pkgconfig(libfguid) >= 20220113
BuildRequires:  pkgconfig(libfvalue) >= 20220120
BuildRequires:  pkgconfig(libhmac) >= 20230407
BuildRequires:  pkgconfig(libuna) >= 20230710
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libbde is a library to access the BitLocker Drive Encryption (BDE)
format. The BDE format is used by Windows, as of Vista, to encrypt
data on a storage media volume.

%package -n %{lname}
Summary:        Library to access Microsoft Bitlocker Drive Encrypted volumes
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %{lname}
libbde is a library to access the BitLocker Drive Encryption (BDE)
format. The BDE format is used by Windows, as of Vista, to encrypt
data on a storage media volume.

Supported BDE formats:

* BitLocker Windows Vista
* BitLocker Windows 7
* BitLocker Windows 8 (Consumer Preview)
* BitLocker To Go

Supported protection methods:

* clear key
* password
* recovery password
* start-up key
* FKEV and/or TWEAK key data

Additional features:

* support for partial encrypted volumes
* zeros out the BDE metadata, matches behavior seen on Windows

%package tools
Summary:        Tools to access Microsoft Bitlocker Drive Encrypted volumes
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Tools to access the BitLocker Drive Encryption (BDE) format. The BDE
format is used by Windows, as of Vista, to encrypt data on a storage
media volume.

%package devel
Summary:        Development files for libbde, used to access Bitlocker Drive Encrypted Volumes
License:        GFDL-1.1-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libbfio-devel

%description devel
libbde is a library to access the BitLocker Drive Encryption (BDE)
format. The BDE format is used by Windows, as of Vista, to encrypt
data on a storage media volume.

This subpackage contains libraries and header files for developing
applications that want to make use of libbde.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* "%buildroot/"
find "%buildroot" -type f -name "*.la" -delete -print
# we have static libs for some reason, trash them
find "%buildroot" -name "*.a" -print -delete

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license COPYING*
%{_libdir}/libbde.so.*

%files -n %name-tools
%license COPYING*
%{_bindir}/bde*
%{_mandir}/man1/bde*.1*

%files -n %name-devel
%license COPYING*
%doc BitLocker_Drive_Encryption_*.pdf
%{_includedir}/libbde.h
%{_includedir}/libbde/
%{_libdir}/libbde.so
%{_libdir}/pkgconfig/libbde.pc
%{_mandir}/man3/libbde.3*

%files %python_files
%license COPYING*
%{python_sitearch}/pybde.so

%changelog
* Mon Nov  6 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231106
  * Updates to the Python bindings
* Mon Jul 31 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Wed Nov  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221031
  * No changelog was provided
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220827
  * No changelog was provided
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220121
  * Unspecified changes to volume unlocking.
* Thu Nov 25 2021 Jan Engelhardt <jengelh@inai.de>
- Add keyring
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210605
  * No changelog was provided
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210425 (585f94c5)
  * No changelog was provided
- Add system-libs.patch
- Added the --enable-wide-character-type flag at build time
* Wed Oct 21 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v20200724
  * changes to handle metadatasize
  * changes for AES-XTS 256 support
  * colde clean up
- add LGPL text
- add README to tools
* Mon Jul  6 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v20191221
  * there are no documented changes except code clean up
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Mon Aug 19 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v20190701
  * worked on AES-XTS 256 support
* Mon Apr  1 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190317
  * worked on AES-XTS support
  * Added support for volumes without metadata value type 0x000f
  * Worked on mount tool
  * Worked on BitLocker Used Disk Space Only encryption format support
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libbde to python2-libbde as expected by singlespec
- remove Provides pybde as it is not versioned
- add python3 binding sub-package
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- update to v0~20170204
- rename BitLocker_Drive_Encryption_BDE_format.pdf file to match new OBS naming rule
- clean-up BuildRequires
* Wed Jan 27 2016 Greg.Freemyer@gmail.com
- update to v0~20160108
  * 2016 update
  * updated dependencies
  * worked on splitting encryption method and copy
  * worked on AES-XTS support
  * code clean up
  * worked on tests
  * worked on signature check
  * added correction for volume size being 1 sector short
  * applied updates
* Fri Jan  9 2015 Greg.Freemyer@gmail.com
- update to v0~20150106
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * worked on test scripts
  * worked on thread-safety
  * code clean up
  * removed libbde_volume_read_random
  * fixed pybde open close test
  * pybde added get encryption method functionality
  * bug fix in Python-bindings
  * worked on utility scripts
  * updates for latest libfdata
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using newly released libyal packages from OBS
- remove %%if opensuse logic.  Not needed now that libyal is in security:forensics
* Thu Aug 21 2014 Greg.Freemyer@gmail.com
- add "Requires:  %%lname = %%version" to python section.
- add provides pybde to python sub-package to match upstream requires statements
- cleaned up BuildRequires statements to allow build for openSUSE 13.1
- ran spec-cleaner
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- initial version v20140731
